/*
 * Give a description to an object.
 */

private string short_desc;
private string long_desc;
/* The short description should not have a newline at the end, nor a '.'. */
void set_short(string str) {
    short_desc = str;
}

/* The long description should include a newline at the end. */
void set_long(string str) {
    long_desc = str;
}

string query_short() {
    return short_desc;
}

string query_long(string str) {
    return long_desc;
}
