/*
 * Define general commands to enable the player to communicate.
 */
void init_comm() {
    add_action("say_cmd", "say");
}

int say_cmd(string str) {
    if (str == 0) {
	notify_fail("Say what ?\n");
	return 0;
    }
    say(this_player()->query_player_name() + " says: " + str + "\n");
    write("Ok.\n");
    return 1;
}
