inherit "/obj/treasure";
void create() {
    set_id(({"xx"}));
    set_short("xx");
    set_long("Lars's xx\n");
}

void init() {
    add_action("xx", "xx");
    add_action("::foobar", "crash");
}

int xx(string str) {
    write(file_size(str) + "\n");
    return 1;
}
