#define DEST "/room/map/m0_1"

inherit "/basic/move";
inherit "/basic/id";

string query_short() {
    return "Lars' workroom";
}

string query_long() {
    return "You are looking at the entrance to Lars' workroom. It is really only\n" +
	"an example of how to make a castle.\n";
}

void init() {
    add_action("enter", "enter");
}

int enter(string str) {
    if (str) {
	str = lower_case(str);
	if (!id(str))
	    return 0;
    }
    this_player()->move_player("/w/lars/workroom", "enters Lars' workroom");
    return 1;
}

void create() {
    set_id(({"workroom", "lars workroom",
		 "lars' workroom", "lars's workroom" }));
    move(DEST);
}
