#include <stats.h>
inherit "/complex/room";

void create()
{
    set_light(1);
    set_short("Lars' workroom");
    set_long(
        "This is Lars' workroom.\n");
    set_exits(
        ({ "/room/map/m0_1", }),
        ({ "north", }));
}
