/*
 *	doordata.c
 *
 *	Special things that doors do.
 *	Must be able to open then obviously.
 *	But lockablity and whether or not they are sliding doors etc should
 *	be defined in classes that inherit from door.
 */
inherit	"/basic/openable";

private object	gateway1,
		gateway2;

set_gateways(object g1, g2)
{
	gateway1 = g1;
	gateway2 = g2;
}

object query_gateway1()
{
	return gateway1;
}

object query_gateway2()
{
	return gateway2;
}

object query_other_gateway(object this_gateway)
{
	if (this_gateway == gateway1) {
		return gateway2;
	}
	else {
		return gateway1;
	}
}

open()
{
	return openable::open();
}

close()
{
	return openable::close();
}
