int comp(int n) {
    n += 0x003f003f;
    n = ((n+2) * n + 2) * n;
    if (n < 0)
	n = -n;
    return n;
}

int rand(int arg) {
    int i;

    for (i = arg; i < arg+20; i++)
	write(comp(i) % 100 + "\n");
}
