/*
 * Send a message to players in the same room. Exclude this_object().
 * If 'str2' and 'whom' is present, send 'str1' to all but 'whom', which
 * will get message 'str1'.
 */
void message(string str1, string str2, object whom) {
    object *all;
    int i;
    string name;

    name = (string)this_object()->query_player_cap_name() + " ";
    all = all_inventory(environment(this_object()));
    for (i=0; i < sizeof(all); i++) {
	if (all[i] == this_object())
	    continue;
	if (all[i] == whom)
	    tell_object(whom, name + str2 + ".\n");
	else
	    tell_object(all[i], name + str1 + ".\n");
    }
}
