/*
 * Give an id to an object.
 */

private string *names;

void set_id(string *new_id) {
    if (!pointerp(new_id))
	return;
    names = new_id;
}

string *query_id() {
    return names;
}

int id(string str) {
    if (names == 0 || member_array(str, names) == -1)
	return 0;
    return 1;
}

