private string player_name;
private static string cap_name;

string query_player_name() {
    return player_name;
}

string query_player_cap_name() {
    return cap_name;
}

void move_player_to_start() {
    /* Just a dummy to be replaced in main player.c */
}

void try_again_another_time() {
    write("Try again another time.\n");
    destruct(this_object());
}

void get_name(string str) {
    if (str == "") {
	try_again_another_time();
	return;
    }
    player_name = lower_case(str);
    cap_name = capitalize(player_name);
    write("Password: ");
    input_to("get_password", 1);
}

void get_password(string str) {
    write("\n");
    if (str == "") {
	try_again_another_time();
	return;
    }
    move_player_to_start();
}

void logon() {
    write("LPmud version " + version() + "\n");
    write("mudlib N.3\n");
    write("Name: ");
    input_to("get_name");
}
