inherit "/basic/id";
inherit "/basic/move";
inherit "/basic/description";
inherit "/basic/value";

/*
 * Sorry, there must be just some program in every object
 * It will be fixed soon !
 */

void dummy() {}
