/*
 *	key_lock.c
 *
 *	Your standard lock with a key.
 */
inherit "/basic/lockdata";

private string	lock_type;

void set_lock_type(string t)
{
	lock_type = t;
}

string query_lock_type()
{
	return lock_type;
}
