/*----------- Most of the gender handling here: ------------*/

private string gender;

void set_gender(string g) {
    if (g == "male" || g == "female" || g == "neuter")
        gender = g;
}

string query_gender() {
    return gender;
}

string query_pronoun() {
    if (gender == "neuter")
	return "it";
    else if (gender == "male")
	return "he";
    else
	return "she";
}

string query_possessive() {
    if (gender == "neuter")
	return "its";
    else if (gender == "male")
	return "his";
    else
	return "her";
}

string query_objective() {
    if (gender == "neuter")
	return "it";
    else if (gender == "male")
	return "him";
    else
	return "her";
}

