#include <stats.h>

inherit "/complex/room";

void create() {
    set_short("A green lawn");
    set_long("You are standing on a big green lawn.\n" +
	     "There is a hedge to the north and east.\n");
    set_exits(({ "/room/start1", "/room/start" }),
	      ({ "west", "south" }) );
    set_item_descriptions(({"hedge", "lawn"}),
			  ({"The hedge looks dense.\n",
			    "There is lot of grass.\n"}));
    set_light(1);
}
