inherit "complex/room";

void create() {
    set_short("The void");
    set_long("You are in the void.\n" +
	     "Give command 'start' to get back to starting point.\n");
    set_exits( ({ "/room/start" }), ({ "start" }) );
    set_light(1);
}

