/*
 *	lock_logic.h
 */
#define	LOCKLOGIC_LOCK_UNLOCKS		1
#define	LOCKLOGIC_LOCK_LOCKS		2
#define	LOCKLOGIC_LOCK_ALREADY_UNLOCKED	3
#define	LOCKLOGIC_LOCK_ALREADY_LOCKED	4
#define	LOCKLOGIC_LOCK_WILL_NOT_UNLOCK	5
#define	LOCKLOGIC_LOCK_WILL_NOT_LOCK	6
