/*
 *	key.c
 *	A key for a lock.
 */
inherit "/basic/id";
inherit "/basic/description";
inherit "/basic/move";

private string	key_type;

void set_key_type(string t)
{
	key_type = t;
}

string query_key_type()
{
	return key_type;
}
