/*
 *	door_logic.h
 */
#define	DOORLOGIC_DOOR_OPENS		1
#define	DOORLOGIC_DOOR_CLOSES		2
#define	DOORLOGIC_DOOR_ALREADY_OPEN	3
#define	DOORLOGIC_DOOR_ALREADY_CLOSED	4
#define	DOORLOGIC_DOOR_WILL_NOT_OPEN	5
#define	DOORLOGIC_DOOR_WILL_NOT_CLOSE	6
